/***********************************************************************************************************************************
Verify Command
***********************************************************************************************************************************/
#ifndef COMMAND_VERIFY_VERIFY_H
#define COMMAND_VERIFY_VERIFY_H

/***********************************************************************************************************************************
Functions
***********************************************************************************************************************************/
// Verify the contents of the repository
FN_EXTERN void cmdVerify(void);

#endif
